@@ -20,14 +20,14 @@ def main():
     parser.add_argument("long", help="longitude (degrees)", type=float)
     parser.add_argument("height", help="ellipsoidal height (meters)", type=float)
 # these are the optional inputs 
-    parser.add_argument("-e1", "--e1", default=None, type=int, help="lower limit elevation angle")
-    parser.add_argument("-e2", "--e2", default=None, type=int, help="upper limit elevation angle")
-    parser.add_argument("-h1", "--h1", default=None, type=float, help="lower limit reflector height (m)")
-    parser.add_argument("-h2", "--h2", default=None, type=float, help="upper limit reflector height (m)")
-    parser.add_argument("-nr1", "--nr1", default=None, type=float, help="lower limit noise region for QC(m)")
-    parser.add_argument("-nr2", "--nr2", default=None, type=float, help="upper limit noise region for QC(m)")
-    parser.add_argument("-peak2noise", "--peak2noise", default=None, type=float, help="peak 2 noise ratio used for QC")
-    parser.add_argument("-allfreq", "--allfreq", default=None, type=str, help="set to True to include all GNSS")
+    parser.add_argument("-e1", , default=None, type=int, help="lower limit elevation angle")
+    parser.add_argument("-e2",  default=None, type=int, help="upper limit elevation angle")
+    parser.add_argument("-h1",  default=None, type=float, help="lower limit reflector height (m)")
+    parser.add_argument("-h2",  default=None, type=float, help="upper limit reflector height (m)")
+    parser.add_argument("-nr1", default=None, type=float, help="lower limit noise region for QC(m)")
+    parser.add_argument("-nr2",  default=None, type=float, help="upper limit noise region for QC(m)")
+    parser.add_argument("-peak2noise",  default=None, type=float, help="peak to noise ratio used for QC")
+    parser.add_argument("-allfreq", default=None, type=str, help="set to True to include all GNSS")
     args = parser.parse_args()
 #
 
